@@ -1,4 +1,4 @@
-/*	$NetBSD: refresh.c,v 1.12 2000/01/20 22:56:21 christos Exp $	*/
+/*	$NetBSD: refresh.c,v 1.14 2000/03/13 22:59:22 soren Exp $	*/
 
 /*-
  * Copyright (c) 1992, 1993
@@ -629,7 +629,7 @@ re_update_line(el, old, new, i)
      * ^.....................^     ^..................^       ^........^
      * \new                  \nfd  \nsb               \nse     \nls    \ne
      *
-     * fx is the difference in length between the the chars between nfd and
+     * fx is the difference in length between the chars between nfd and
      * nsb, and the chars between ofd and osb, and is thus the number of
      * characters to delete if < 0 (new is shorter than old, as above),
      * or insert (new is longer than short).
@@ -739,7 +739,7 @@ re_update_line(el, old, new, i)
     else
 	fx = 0;
 
-    if (sx < 0) {
+    if (sx < 0 && (ose - old) + fx < el->el_term.t_size.h) {
 	ELRE_DEBUG(1,(__F, "second diff delete at %d...\r\n", (ose - old) + fx),);
 	/*
 	 * Check if we have stuff to delete
@@ -772,7 +772,8 @@ re_update_line(el, old, new, i)
 	    ELRE_DEBUG(1,(__F, "but with nothing left to save\r\n"),);
 	    term_overwrite(el, nse, (nls - nse));
 	    ELRE_DEBUG(1,(__F, "cleareol %d\n", (oe - old) - (ne - new)),);
-	    term_clear_EOL(el, (oe - old) - (ne - new));
+	    if ((oe - old) - (ne - new) != 0)
+		term_clear_EOL(el, (oe - old) - (ne - new));
 	}
     }
 
