@@ -1,7 +1,7 @@
-/*	$NetBSD: cmds.c,v 1.82 2000/01/31 22:01:03 lukem Exp $	*/
+/*	$NetBSD: cmds.c,v 1.86 2000/05/28 07:53:30 lukem Exp $	*/
 
 /*-
- * Copyright (c) 1996-1999 The NetBSD Foundation, Inc.
+ * Copyright (c) 1996-2000 The NetBSD Foundation, Inc.
  * All rights reserved.
  *
  * This code is derived from software contributed to The NetBSD Foundation
@@ -128,11 +128,10 @@ struct	types {
 sigjmp_buf	 jabort;
 char		*mname;
 
-static int	confirm __P((const char *, const char *));
+static int	confirm(const char *, const char *);
 
 static int
-confirm(cmd, file)
-	const char *cmd, *file;
+confirm(const char *cmd, const char *file)
 {
 	char line[BUFSIZ];
 
@@ -184,9 +183,7 @@ confirm(cmd, file)
  * Set transfer type.
  */
 void
-settype(argc, argv)
-	int argc;
-	char *argv[];
+settype(int argc, char *argv[])
 {
 	struct types *p;
 	int comret;
@@ -233,8 +230,7 @@ settype(argc, argv)
  * Used to change to and from ascii for listings.
  */
 void
-changetype(newtype, show)
-	int newtype, show;
+changetype(int newtype, int show)
 {
 	struct types *p;
 	int comret, oldverbose = verbose;
@@ -272,9 +268,7 @@ char *stype[] = {
  */
 /*VARARGS*/
 void
-setbinary(argc, argv)
-	int argc;
-	char *argv[];
+setbinary(int argc, char *argv[])
 {
 
 	if (argc == 0 && argv != NULL) {
@@ -291,9 +285,7 @@ setbinary(argc, argv)
  */
 /*VARARGS*/
 void
-setascii(argc, argv)
-	int argc;
-	char *argv[];
+setascii(int argc, char *argv[])
 {
 
 	if (argc == 0 && argv != NULL) {
@@ -310,9 +302,7 @@ setascii(argc, argv)
  */
 /*VARARGS*/
 void
-settenex(argc, argv)
-	int argc;
-	char *argv[];
+settenex(int argc, char *argv[])
 {
 
 	if (argc == 0 && argv != NULL) {
@@ -329,9 +319,7 @@ settenex(argc, argv)
  */
 /*ARGSUSED*/
 void
-setftmode(argc, argv)
-	int argc;
-	char *argv[];
+setftmode(int argc, char *argv[])
 {
 
 	if ((argc == 0 && argv != NULL) || argc != 2) {
@@ -348,9 +336,7 @@ setftmode(argc, argv)
  */
 /*ARGSUSED*/
 void
-setform(argc, argv)
-	int argc;
-	char *argv[];
+setform(int argc, char *argv[])
 {
 
 	if ((argc == 0 && argv != NULL) || argc != 2) {
@@ -367,9 +353,7 @@ setform(argc, argv)
  */
 /*ARGSUSED*/
 void
-setstruct(argc, argv)
-	int argc;
-	char *argv[];
+setstruct(int argc, char *argv[])
 {
 
 	if ((argc == 0 && argv != NULL) || argc != 2) {
@@ -385,9 +369,7 @@ setstruct(argc, argv)
  * Send a single file.
  */
 void
-put(argc, argv)
-	int argc;
-	char *argv[];
+put(int argc, char *argv[])
 {
 	char *cmd;
 	int loc = 0;
@@ -429,9 +411,7 @@ usage:
  * Send multiple files.
  */
 void
-mput(argc, argv)
-	int argc;
-	char *argv[];
+mput(int argc, char *argv[])
 {
 	int i;
 	sigfunc oldintr;
@@ -534,18 +514,14 @@ cleanupmput:
 }
 
 void
-reget(argc, argv)
-	int argc;
-	char *argv[];
+reget(int argc, char *argv[])
 {
 
 	(void)getit(argc, argv, 1, "r+w");
 }
 
 void
-get(argc, argv)
-	int argc;
-	char *argv[];
+get(int argc, char *argv[])
 {
 
 	(void)getit(argc, argv, 0, restart_point ? "r+w" : "w" );
@@ -555,11 +531,7 @@ get(argc, argv)
  * Receive one file.
  */
 int
-getit(argc, argv, restartit, mode)
-	int argc;
-	char *argv[];
-	int restartit;
-	const char *mode;
+getit(int argc, char *argv[], int restartit, const char *mode)
 {
 	int loc = 0;
 	int rval = 0;
@@ -628,8 +600,7 @@ freegetit:
 
 /* ARGSUSED */
 void
-mintr(signo)
-	int signo;
+mintr(int signo)
 {
 
 	alarmtimer(0);
@@ -639,7 +610,7 @@ mintr(signo)
 }
 
 void
-mabort()
+mabort(void)
 {
 	int ointer, oconf;
 
@@ -663,9 +634,7 @@ mabort()
  * Get multiple files.
  */
 void
-mget(argc, argv)
-	int argc;
-	char *argv[];
+mget(int argc, char *argv[])
 {
 	sigfunc oldintr;
 	int ch, ointer;
@@ -717,9 +686,44 @@ mget(argc, argv)
 	mflag = 0;
 }
 
+/*
+ * Read list of filenames from a local file and get those
+ */
+void
+fget(int argc, char *argv[])
+{
+	char	*buf, *mode;
+	FILE	*fp;
+
+	if (argc != 2) {
+		fprintf(ttyout, "usage: %s localfile\n", argv[0]);
+		code = -1;
+		return;
+	}
+
+	fp = fopen(argv[1], "r");
+	if (fp == NULL) {
+		fprintf(ttyout, "Cannot open source file %s\n", argv[1]);
+		code = -1;
+		return;
+	}
+
+	argv[0] = "get";
+	mode = restart_point ? "r+w" : "w";
+
+	for (;
+	    (buf = fparseln(fp, NULL, NULL, "\0\0\0", 0)) != NULL;
+	    free(buf)) {
+		if (buf[0] == '\0')
+			continue;
+		argv[1] = buf;
+		(void)getit(argc, argv, 0, mode);
+	}
+	fclose(fp);
+}
+
 char *
-onoff(bool)
-	int bool;
+onoff(int bool)
 {
 
 	return (bool ? "on" : "off");
@@ -730,9 +734,7 @@ onoff(bool)
  */
 /*ARGSUSED*/
 void
-status(argc, argv)
-	int argc;
-	char *argv[];
+status(int argc, char *argv[])
 {
 	int i;
 
@@ -818,11 +820,7 @@ status(argc, argv)
  * Toggle a variable
  */
 int
-togglevar(argc, argv, var, mesg)
-	int   argc;
-	char *argv[];
-	int  *var;
-	const char *mesg;
+togglevar(int argc, char *argv[], int *var, const char *mesg)
 {
 	if (argc == 1) {
 		*var = !*var;
@@ -844,9 +842,7 @@ togglevar(argc, argv, var, mesg)
  */
 /*VARARGS*/
 void
-setbell(argc, argv)
-	int argc;
-	char *argv[];
+setbell(int argc, char *argv[])
 {
 
 	code = togglevar(argc, argv, &bell, "Bell mode");
@@ -857,9 +853,7 @@ setbell(argc, argv)
  */
 /*VARARGS*/
 void
-setedit(argc, argv)
-	int argc;
-	char *argv[];
+setedit(int argc, char *argv[])
 {
 
 #ifdef NO_EDITCOMPLETE
@@ -882,9 +876,7 @@ setedit(argc, argv)
  */
 /*VARARGS*/
 void
-settrace(argc, argv)
-	int argc;
-	char *argv[];
+settrace(int argc, char *argv[])
 {
 
 	code = togglevar(argc, argv, &trace, "Packet tracing");
@@ -895,9 +887,7 @@ settrace(argc, argv)
  */
 /*VARARGS*/
 void
-sethash(argc, argv)
-	int argc;
-	char *argv[];
+sethash(int argc, char *argv[])
 {
 	if (argc == 1)
 		hash = !hash;
@@ -937,9 +927,7 @@ sethash(argc, argv)
  */
 /*VARARGS*/
 void
-setverbose(argc, argv)
-	int argc;
-	char *argv[];
+setverbose(int argc, char *argv[])
 {
 
 	code = togglevar(argc, argv, &verbose, "Verbose mode");
@@ -950,9 +938,7 @@ setverbose(argc, argv)
  */
 /*VARARGS*/
 void
-setport(argc, argv)
-	int argc;
-	char *argv[];
+setport(int argc, char *argv[])
 {
 
 	code = togglevar(argc, argv, &sendport, "Use of PORT/LPRT cmds");
@@ -963,9 +949,7 @@ setport(argc, argv)
  */
 /*VARARGS*/
 void
-setprogress(argc, argv)
-	int argc;
-	char *argv[];
+setprogress(int argc, char *argv[])
 {
 
 	code = togglevar(argc, argv, &progress, "Progress bar");
@@ -978,9 +962,7 @@ setprogress(argc, argv)
  */
 /*VARARGS*/
 void
-setprompt(argc, argv)
-	int argc;
-	char *argv[];
+setprompt(int argc, char *argv[])
 {
 
 	code = togglevar(argc, argv, &interactive, "Interactive mode");
@@ -991,9 +973,7 @@ setprompt(argc, argv)
  */
 /*VARARGS*/
 void
-setgate(argc, argv)
-	int argc;
-	char *argv[];
+setgate(int argc, char *argv[])
 {
 	static char gsbuf[MAXHOSTNAMELEN];
 
@@ -1034,9 +1014,7 @@ setgate(argc, argv)
  */
 /*VARARGS*/
 void
-setglob(argc, argv)
-	int argc;
-	char *argv[];
+setglob(int argc, char *argv[])
 {
 
 	code = togglevar(argc, argv, &doglob, "Globbing");
@@ -1047,9 +1025,7 @@ setglob(argc, argv)
  */
 /*VARARGS*/
 void
-setpreserve(argc, argv)
-	int argc;
-	char *argv[];
+setpreserve(int argc, char *argv[])
 {
 
 	code = togglevar(argc, argv, &preserve, "Preserve modification times");
@@ -1060,9 +1036,7 @@ setpreserve(argc, argv)
  */
 /*VARARGS*/
 void
-setdebug(argc, argv)
-	int argc;
-	char *argv[];
+setdebug(int argc, char *argv[])
 {
 	if ((argc == 0 && argv != NULL) || argc > 2) {
 		fprintf(ttyout, "usage: %s [ on | off | debuglevel ]\n",
@@ -1100,9 +1074,7 @@ setdebug(argc, argv)
  * Set current working directory on remote machine.
  */
 void
-cd(argc, argv)
-	int argc;
-	char *argv[];
+cd(int argc, char *argv[])
 {
 	int r;
 
@@ -1129,9 +1101,7 @@ cd(argc, argv)
  * Set current working directory on local machine.
  */
 void
-lcd(argc, argv)
-	int argc;
-	char *argv[];
+lcd(int argc, char *argv[])
 {
 	char buf[MAXPATHLEN];
 	char *locdir;
@@ -1163,11 +1133,10 @@ lcd(argc, argv)
  * Delete a single file.
  */
 void
-delete(argc, argv)
-	int argc;
-	char *argv[];
+delete(int argc, char *argv[])
 {
 
+
 	if ((argc == 1 && !another(&argc, &argv, "remote-file")) ||
 	    (argc == 0 && argv != NULL) || argc > 2) {
 		fprintf(ttyout, "usage: %s remote-file\n", argv[0]);
@@ -1181,9 +1150,7 @@ delete(argc, argv)
  * Delete multiple files.
  */
 void
-mdelete(argc, argv)
-	int argc;
-	char *argv[];
+mdelete(int argc, char *argv[])
 {
 	sigfunc oldintr;
 	int ointer;
@@ -1225,9 +1192,7 @@ mdelete(argc, argv)
  * Rename a remote file.
  */
 void
-renamefile(argc, argv)
-	int argc;
-	char *argv[];
+renamefile(int argc, char *argv[])
 {
 
 	if ((argc == 0 && argv != NULL) ||
@@ -1247,9 +1212,7 @@ usage:
  * Get a directory listing of remote files.
  */
 void
-ls(argc, argv)
-	int argc;
-	char *argv[];
+ls(int argc, char *argv[])
 {
 	const char *cmd;
 	char *remdir, *locfile;
@@ -1267,9 +1230,9 @@ ls(argc, argv)
 	if (argc == 0 && argv != NULL)
 		goto usage;
 
-	cmd = "NLST";
-	if (strcmp(argv[0] + pagecmd, "dir") == 0)
-		cmd = "LIST";
+	cmd = "LIST";
+	if (strcmp(argv[0], "nlist") == 0)
+		cmd = "NLST";
 
 	if (argc > 1)
 		remdir = argv[1];
@@ -1318,9 +1281,7 @@ freels:
  * Get a directory listing of multiple remote files.
  */
 void
-mls(argc, argv)
-	int argc;
-	char *argv[];
+mls(int argc, char *argv[])
 {
 	sigfunc oldintr;
 	int ointer, i;
@@ -1375,9 +1336,7 @@ usage:
  */
 /*ARGSUSED*/
 void
-shell(argc, argv)
-	int argc;
-	char *argv[];
+shell(int argc, char *argv[])
 {
 	pid_t pid;
 	sigfunc old1;
@@ -1432,9 +1391,7 @@ shell(argc, argv)
  * Send new user information (re-login)
  */
 void
-user(argc, argv)
-	int argc;
-	char *argv[];
+user(int argc, char *argv[])
 {
 	char acct[80];
 	int n, aflag = 0;
@@ -1490,9 +1447,7 @@ user(argc, argv)
  */
 /*VARARGS*/
 void
-pwd(argc, argv)
-	int argc;
-	char *argv[];
+pwd(int argc, char *argv[])
 {
 	int oldverbose = verbose;
 
@@ -1516,9 +1471,7 @@ pwd(argc, argv)
  * Print working directory on local machine.
  */
 void
-lpwd(argc, argv)
-	int argc;
-	char *argv[];
+lpwd(int argc, char *argv[])
 {
 	char buf[MAXPATHLEN];
 
@@ -1540,9 +1493,7 @@ lpwd(argc, argv)
  * Make a directory.
  */
 void
-makedir(argc, argv)
-	int argc;
-	char *argv[];
+makedir(int argc, char *argv[])
 {
 
 	if ((argc == 1 && !another(&argc, &argv, "directory-name")) ||
@@ -1563,9 +1514,7 @@ makedir(argc, argv)
  * Remove a directory.
  */
 void
-removedir(argc, argv)
-	int argc;
-	char *argv[];
+removedir(int argc, char *argv[])
 {
 
 	if ((argc == 1 && !another(&argc, &argv, "directory-name")) ||
@@ -1586,9 +1535,7 @@ removedir(argc, argv)
  * Send a line, verbatim, to the remote machine.
  */
 void
-quote(argc, argv)
-	int argc;
-	char *argv[];
+quote(int argc, char *argv[])
 {
 
 	if ((argc == 1 && !another(&argc, &argv, "command line to send")) ||
@@ -1606,9 +1553,7 @@ quote(argc, argv)
  * word "SITE" is added at the front.
  */
 void
-site(argc, argv)
-	int argc;
-	char *argv[];
+site(int argc, char *argv[])
 {
 
 	if ((argc == 1 && !another(&argc, &argv, "arguments to SITE command"))
@@ -1625,10 +1570,7 @@ site(argc, argv)
  * Send the result as a one-line command and get response.
  */
 void
-quote1(initial, argc, argv)
-	const char *initial;
-	int argc;
-	char *argv[];
+quote1(const char *initial, int argc, char *argv[])
 {
 	int i;
 	char buf[BUFSIZ];		/* must be >= sizeof(line) */
@@ -1646,9 +1588,7 @@ quote1(initial, argc, argv)
 }
 
 void
-do_chmod(argc, argv)
-	int argc;
-	char *argv[];
+do_chmod(int argc, char *argv[])
 {
 
 	if ((argc == 0 && argv != NULL) ||
@@ -1664,9 +1604,7 @@ usage:
 }
 
 void
-do_umask(argc, argv)
-	int argc;
-	char *argv[];
+do_umask(int argc, char *argv[])
 {
 	int oldverbose = verbose;
 
@@ -1681,9 +1619,7 @@ do_umask(argc, argv)
 }
 
 void
-idlecmd(argc, argv)
-	int argc;
-	char *argv[];
+idlecmd(int argc, char *argv[])
 {
 	int oldverbose = verbose;
 
@@ -1701,9 +1637,7 @@ idlecmd(argc, argv)
  * Ask the other side for help.
  */
 void
-rmthelp(argc, argv)
-	int argc;
-	char *argv[];
+rmthelp(int argc, char *argv[])
 {
 	int oldverbose = verbose;
 
@@ -1722,9 +1656,7 @@ rmthelp(argc, argv)
  */
 /*VARARGS*/
 void
-quit(argc, argv)
-	int argc;
-	char *argv[];
+quit(int argc, char *argv[])
 {
 
 	if (argc == 0 && argv != NULL) {
@@ -1744,9 +1676,7 @@ quit(argc, argv)
  * Terminate session, but don't exit.
  */
 void
-disconnect(argc, argv)
-	int argc;
-	char *argv[];
+disconnect(int argc, char *argv[])
 {
 
 	if (argc == 0 && argv != NULL) {
@@ -1761,9 +1691,7 @@ disconnect(argc, argv)
 }
 
 void
-account(argc, argv)
-	int argc;
-	char *argv[];
+account(int argc, char *argv[])
 {
 	char *ap;
 
@@ -1782,8 +1710,7 @@ account(argc, argv)
 sigjmp_buf abortprox;
 
 void
-proxabort(notused)
-	int notused;
+proxabort(int notused)
 {
 
 	alarmtimer(0);
@@ -1801,9 +1728,7 @@ proxabort(notused)
 }
 
 void
-doproxy(argc, argv)
-	int argc;
-	char *argv[];
+doproxy(int argc, char *argv[])
 {
 	struct cmd *c;
 	int cmdpos;
@@ -1859,9 +1784,7 @@ doproxy(argc, argv)
 }
 
 void
-setcase(argc, argv)
-	int argc;
-	char *argv[];
+setcase(int argc, char *argv[])
 {
 
 	code = togglevar(argc, argv, &mcase, "Case mapping");
@@ -1872,8 +1795,7 @@ setcase(argc, argv)
  * a static buffer which is returned to the caller
  */
 char *
-docase(name)
-	char *name;
+docase(char *name)
 {
 	static char new[MAXPATHLEN];
 	int i, dochange;
@@ -1895,18 +1817,14 @@ docase(name)
 }
 
 void
-setcr(argc, argv)
-	int argc;
-	char *argv[];
+setcr(int argc, char *argv[])
 {
 
 	code = togglevar(argc, argv, &crflag, "Carriage Return stripping");
 }
 
 void
-setntrans(argc, argv)
-	int argc;
-	char *argv[];
+setntrans(int argc, char *argv[])
 {
 
 	if ((argc == 0 && argv != NULL) || argc > 3) {
@@ -1931,8 +1849,7 @@ setntrans(argc, argv)
 }
 
 char *
-dotrans(name)
-	char *name;
+dotrans(char *name)
 {
 	static char new[MAXPATHLEN];
 	char *cp1, *cp2 = new;
@@ -1960,9 +1877,7 @@ dotrans(name)
 }
 
 void
-setnmap(argc, argv)
-	int argc;
-	char *argv[];
+setnmap(int argc, char *argv[])
 {
 	char *cp;
 
@@ -1995,8 +1910,7 @@ setnmap(argc, argv)
 }
 
 char *
-domap(name)
-	char *name;
+domap(char *name)
 {
 	static char new[MAXPATHLEN];
 	char *cp1 = name, *cp2 = mapin;
@@ -2170,9 +2084,7 @@ LOOP:
 }
 
 void
-setpassive(argc, argv)
-	int argc;
-	char *argv[];
+setpassive(int argc, char *argv[])
 {
 
 	if (argc == 1) {
@@ -2200,9 +2112,7 @@ setpassive(argc, argv)
 }
 
 void
-setepsv4(argc, argv)
-	int argc;
-	char *argv[];
+setepsv4(int argc, char *argv[])
 {
 
 	code = togglevar(argc, argv, &epsv4,
@@ -2211,28 +2121,21 @@ setepsv4(argc, argv)
 }
 
 void
-setsunique(argc, argv)
-	int argc;
-	char *argv[];
+setsunique(int argc, char *argv[])
 {
 
 	code = togglevar(argc, argv, &sunique, "Store unique");
 }
 
 void
-setrunique(argc, argv)
-	int argc;
-	char *argv[];
+setrunique(int argc, char *argv[])
 {
 
 	code = togglevar(argc, argv, &runique, "Receive unique");
 }
 
 int
-parserate(argc, argv, cmdlineopt)
-	int argc;
-	char *argv[];
-	int cmdlineopt;
+parserate(int argc, char *argv[], int cmdlineopt)
 {
 	int dir, max, incr, showonly;
 	sigfunc oldusr1, oldusr2;
@@ -2303,9 +2206,7 @@ usage:
 }
 
 void
-setrate(argc, argv)
-	int argc;
-	char *argv[];
+setrate(int argc, char *argv[])
 {
 
 	code = parserate(argc, argv, 0);
@@ -2313,9 +2214,7 @@ setrate(argc, argv)
 
 /* change directory to parent directory */
 void
-cdup(argc, argv)
-	int argc;
-	char *argv[];
+cdup(int argc, char *argv[])
 {
 	int r;
 
@@ -2341,9 +2240,7 @@ cdup(argc, argv)
  * Restart transfer at specific point
  */
 void
-restart(argc, argv)
-	int argc;
-	char *argv[];
+restart(int argc, char *argv[])
 {
 
 	if ((argc == 0 && argv != NULL) || argc > 2) {
@@ -2356,7 +2253,7 @@ restart(argc, argv)
 		char *ep;
 
 #ifndef NO_QUAD
-		rp = strtoq(argv[1], &ep, 10);
+		rp = strtoll(argv[1], &ep, 10);
 #else
 		rp = strtol(argv[1], &ep, 10);
 #endif
@@ -2383,9 +2280,7 @@ restart(argc, argv)
  * Show remote system type
  */
 void
-syst(argc, argv)
-	int argc;
-	char *argv[];
+syst(int argc, char *argv[])
 {
 
 	if (argc == 0 && argv != NULL) {
@@ -2397,9 +2292,7 @@ syst(argc, argv)
 }
 
 void
-macdef(argc, argv)
-	int argc;
-	char *argv[];
+macdef(int argc, char *argv[])
 {
 	char *tmp;
 	int c;
@@ -2466,9 +2359,7 @@ macdef(argc, argv)
  * Get size of file on remote machine
  */
 void
-sizecmd(argc, argv)
-	int argc;
-	char *argv[];
+sizecmd(int argc, char *argv[])
 {
 	off_t size;
 
@@ -2493,9 +2384,7 @@ sizecmd(argc, argv)
  * Get last modification time of file on remote machine
  */
 void
-modtime(argc, argv)
-	int argc;
-	char *argv[];
+modtime(int argc, char *argv[])
 {
 	time_t mtime;
 
@@ -2515,9 +2404,7 @@ modtime(argc, argv)
  * Show status on remote machine
  */
 void
-rmtstatus(argc, argv)
-	int argc;
-	char *argv[];
+rmtstatus(int argc, char *argv[])
 {
 
 	if (argc == 0 && argv != NULL) {
@@ -2532,9 +2419,7 @@ rmtstatus(argc, argv)
  * Get file if modtime is more recent than current file
  */
 void
-newer(argc, argv)
-	int argc;
-	char *argv[];
+newer(int argc, char *argv[])
 {
 
 	if (getit(argc, argv, -1, "w"))
@@ -2547,9 +2432,7 @@ newer(argc, argv)
  * Display one local file through $PAGER.
  */
 void
-lpage(argc, argv)
-	int argc;
-	char *argv[];
+lpage(int argc, char *argv[])
 {
 	int len;
 	char *p, *pager, *locfile;
@@ -2582,9 +2465,7 @@ lpage(argc, argv)
  * Display one remote file through $PAGER.
  */
 void
-page(argc, argv)
-	int argc;
-	char *argv[];
+page(int argc, char *argv[])
 {
 	int ohash, orestart_point, overbose, len;
 	char *p, *pager;
@@ -2618,9 +2499,7 @@ page(argc, argv)
  * Set the socket send or receive buffer size.
  */
 void
-setxferbuf(argc, argv)
-	int argc;
-	char *argv[];
+setxferbuf(int argc, char *argv[])
 {
 	int size, dir;
 
@@ -2660,9 +2539,7 @@ setxferbuf(argc, argv)
  * Set or display options (defaults are provided by various env vars)
  */
 void
-setoption(argc, argv)
-	int argc;
-	char *argv[];
+setoption(int argc, char *argv[])
 {
 	struct option *o;
 
@@ -2697,9 +2574,7 @@ setoption(argc, argv)
  * Unset an option
  */
 void
-unsetoption(argc, argv)
-	int argc;
-	char *argv[];
+unsetoption(int argc, char *argv[])
 {
 	struct option *o;
 
