@@ -1,12 +1,15 @@
-/*	$NetBSD: fetch.c,v 1.104 2000/01/31 22:01:04 lukem Exp $	*/
+/*	$NetBSD: fetch.c,v 1.115 2000/06/05 09:22:52 lukem Exp $	*/
 
 /*-
- * Copyright (c) 1997-1999 The NetBSD Foundation, Inc.
+ * Copyright (c) 1997-2000 The NetBSD Foundation, Inc.
  * All rights reserved.
  *
  * This code is derived from software contributed to The NetBSD Foundation
  * by Luke Mewburn.
  *
+ * This code is derived from software contributed to The NetBSD Foundation
+ * by Scott Aaron Bamford.
+ *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
@@ -40,7 +43,6 @@
  * FTP User Program -- Command line file retrieval
  */
 
-
 #include "lukemftp.h"
 #include "ftp_var.h"
 #include "version.h"
@@ -53,17 +55,15 @@ typedef enum {
 	CLASSIC_URL_T
 } url_t;
 
-void		aborthttp __P((int));
-static int	auth_url __P((const char *, char **, const char *,
-				const char *));
-static void	base64_encode __P((const char *, size_t, char *));
-static int	go_fetch __P((const char *));
-static int	fetch_ftp __P((const char *));
-static int	fetch_url __P((const char *, const char *, char *, char *));
-static int	parse_url __P((const char *, const char *, url_t *, char **,
-				char **, char **, char **, in_port_t *,
-				char **));
-static void	url_decode __P((char *));
+void		aborthttp(int);
+static int	auth_url(const char *, char **, const char *, const char *);
+static void	base64_encode(const char *, size_t, char *);
+static int	go_fetch(const char *);
+static int	fetch_ftp(const char *);
+static int	fetch_url(const char *, const char *, char *, char *);
+static int	parse_url(const char *, const char *, url_t *, char **,
+			    char **, char **, char **, in_port_t *, char **);
+static void	url_decode(char *);
 
 static int	redirect_loop;
 
@@ -80,11 +80,8 @@ static int	redirect_loop;
  * Sets response to a malloc(3)ed string; caller should free.
  */
 static int
-auth_url(challenge, response, guser, gpass)
-	const char	 *challenge;
-	char		**response;
-	const char	 *guser;
-	const char	 *gpass;
+auth_url(const char *challenge, char **response, const char *guser,
+	const char *gpass)
 {
 	char		*cp, *ep, *clear, *line, *realm, *scheme;
 	char		 user[BUFSIZ], *pass;
@@ -173,10 +170,7 @@ cleanup_auth_url:
  * which should be at least ((len + 2) * 4 / 3 + 1) in size.
  */
 void
-base64_encode(clear, len, encoded)
-	const char	*clear;
-	size_t		 len;
-	char		*encoded;
+base64_encode(const char *clear, size_t len, char *encoded)
 {
 	static const char enc[] =
 	    "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
@@ -201,8 +195,7 @@ base64_encode(clear, len, encoded)
  * Decode %xx escapes in given string, `in-place'.
  */
 static void
-url_decode(url)
-	char *url;
+url_decode(char *url)
 {
 	unsigned char *p, *q;
 
@@ -256,16 +249,9 @@ url_decode(url)
  *	"ftp://host//dir/file"		"/dir/file"
  */
 static int
-parse_url(url, desc, type, user, pass, host, port, portnum, path)
-	const char	 *url;
-	const char	 *desc;
-	url_t		 *type;
-	char		**user;
-	char		**pass;
-	char		**host;
-	char		**port;
-	in_port_t	 *portnum;
-	char		**path;
+parse_url(const char *url, const char *desc, url_t *type,
+		char **user, char **pass, char **host, char **port,
+		in_port_t *portnum, char **path)
 {
 	const char	*origurl;
 	char		*cp, *ep, *thost, *tport;
@@ -345,7 +331,7 @@ cleanup_parse_url:
 	if (*thost == '[') {
 		cp = thost + 1;
 		if ((ep = strchr(cp, ']')) == NULL ||
-		    (ep[1] != '\0' && ep[1] != '\0')) {
+		    (ep[1] != '\0' && ep[1] != ':')) {
 			warnx("Invalid address `%s' in %s `%s'",
 			    thost, desc, origurl);
 			goto cleanup_parse_url;
@@ -400,7 +386,8 @@ cleanup_parse_url:
 
 	if (debug)
 		fprintf(ttyout,
-		    "parse_url: user `%s' pass `%s' host %s:%s(%d) path `%s'\n",
+		    "parse_url: user `%s' pass `%s' host %s port %s(%d) "
+		    "path `%s'\n",
 		    *user ? *user : "<null>", *pass ? *pass : "<null>",
 		    *host ? *host : "<null>", *port ? *port : "<null>",
 		    *portnum ? *portnum : -1, *path ? *path : "<null>");
@@ -419,13 +406,9 @@ sigjmp_buf	httpabort;
  * is still open (e.g, ftp xfer with trailing /)
  */
 static int
-fetch_url(url, proxyenv, proxyauth, wwwauth)
-	const char	*url;
-	const char	*proxyenv;
-	char		*proxyauth;
-	char		*wwwauth;
+fetch_url(const char *url, const char *proxyenv, char *proxyauth, char *wwwauth)
 {
-#ifdef NI_NUMERICHOST
+#if defined(NI_NUMERICHOST) && defined(INET6)
 	struct addrinfo		hints, *res, *res0 = NULL;
 	int			error;
 	char			hbuf[NI_MAXHOST];
@@ -445,7 +428,7 @@ fetch_url(url, proxyenv, proxyauth, wwwauth)
 	char			*user, *pass, *host, *port, *path, *decodedpath;
 	char			*puser, *ppass;
 	off_t			hashbytes, rangestart, rangeend, entitylen;
-	int			 (*closefunc) __P((FILE *));
+	int			 (*closefunc)(FILE *);
 	FILE			*fin, *fout;
 	time_t			mtime;
 	url_t			urltype;
@@ -601,6 +584,8 @@ fetch_url(url, proxyenv, proxyauth, wwwauth)
 							continue;
 					}
 					plen = strlen(cp);
+					if (hlen < plen)
+						continue;
 					if (strncasecmp(host + hlen - plen,
 					    cp, plen) == 0) {
 						isproxy = 0;
@@ -628,6 +613,16 @@ fetch_url(url, proxyenv, proxyauth, wwwauth)
 					FREEPTR(ppath);
 					goto cleanup_fetch_url;
 				}
+				if (isipv6addr(host) &&
+				    strchr(host, '%') != NULL) {
+					warnx(
+"Scoped address notation `%s' disallowed via web proxy",
+					    host);
+					FREEPTR(phost);
+					FREEPTR(pport);
+					FREEPTR(ppath);
+					goto cleanup_fetch_url;
+				}
 
 				FREEPTR(host);
 				host = phost;
@@ -639,7 +634,7 @@ fetch_url(url, proxyenv, proxyauth, wwwauth)
 			}
 		} /* ! EMPTYSTRING(proxyenv) */
 
-#ifndef NI_NUMERICHOST
+#if !defined(NI_NUMERICHOST) || !defined(INET6)
 		memset(&sin, 0, sizeof(sin));
 		sin.sin_family = AF_INET;
 
@@ -714,6 +709,10 @@ fetch_url(url, proxyenv, proxyauth, wwwauth)
 
 		s = -1;
 		for (res = res0; res; res = res->ai_next) {
+			/*
+			 * see comment in hookup()
+			 */
+			ai_unmapped(res);
 			if (getnameinfo(res->ai_addr, res->ai_addrlen,
 					hbuf, sizeof(hbuf), NULL, 0,
 					NI_NUMERICHOST) != 0)
@@ -767,7 +766,22 @@ fetch_url(url, proxyenv, proxyauth, wwwauth)
 				fprintf(fin, "Pragma: no-cache\r\n");
 		} else {
 			fprintf(fin, "GET %s HTTP/1.1\r\n", path);
-			fprintf(fin, "Host: %s:%d\r\n", host, portnum);
+			if (strchr(host, ':')) {
+				char *h, *p;
+
+				/*
+				 * strip off IPv6 scope identifier, since it is
+				 * local to the node
+				 */
+				h = xstrdup(host);
+				if (isipv6addr(h) &&
+				    (p = strchr(h, '%')) != NULL) {
+					*p = '\0';
+				}
+				fprintf(fin, "Host: [%s]:%d\r\n", h, portnum);
+				free(h);
+			} else
+				fprintf(fin, "Host: %s:%d\r\n", host, portnum);
 			fprintf(fin, "Accept: */*\r\n");
 			fprintf(fin, "Connection: close\r\n");
 			if (restart_point) {
@@ -861,7 +875,7 @@ fetch_url(url, proxyenv, proxyauth, wwwauth)
 					sizeof(CONTENTLEN) - 1) == 0) {
 				cp += sizeof(CONTENTLEN) - 1;
 #ifndef NO_QUAD
-				filesize = strtoq(cp, &ep, 10);
+				filesize = strtoll(cp, &ep, 10);
 #else
 				filesize = strtol(cp, &ep, 10);
 #endif
@@ -881,7 +895,7 @@ fetch_url(url, proxyenv, proxyauth, wwwauth)
 					sizeof(CONTENTRANGE) - 1) == 0) {
 				cp += sizeof(CONTENTRANGE) - 1;
 #ifndef NO_QUAD
-				rangestart = strtoq(cp, &ep, 10);
+				rangestart = strtoll(cp, &ep, 10);
 #else
 				rangestart = strtol(cp, &ep, 10);
 #endif
@@ -890,7 +904,7 @@ fetch_url(url, proxyenv, proxyauth, wwwauth)
 				cp = ep + 1;
 
 #ifndef NO_QUAD
-				rangeend = strtoq(cp, &ep, 10);
+				rangeend = strtoll(cp, &ep, 10);
 #else
 				rangeend = strtol(cp, &ep, 10);
 #endif
@@ -900,7 +914,7 @@ fetch_url(url, proxyenv, proxyauth, wwwauth)
 				cp = ep + 1;
 
 #ifndef NO_QUAD
-				entitylen = strtoq(cp, &ep, 10);
+				entitylen = strtoll(cp, &ep, 10);
 #else
 				entitylen = strtol(cp, &ep, 10);
 #endif
@@ -969,6 +983,12 @@ fetch_url(url, proxyenv, proxyauth, wwwauth)
 			} else if (strncasecmp(cp, TRANSENC,
 						sizeof(TRANSENC) - 1) == 0) {
 				cp += sizeof(TRANSENC) - 1;
+				if (strcasecmp(cp, "binary") == 0) {
+					warnx(
+			"Bogus transfer encoding - `%s' (fetching anyway)",
+					    cp);
+					continue;
+				}
 				if (strcasecmp(cp, "chunked") != 0) {
 					warnx(
 				    "Unsupported transfer encoding - `%s'",
@@ -1306,8 +1326,7 @@ cleanup_fetch_url:
  * Abort a HTTP retrieval
  */
 void
-aborthttp(notused)
-	int notused;
+aborthttp(int notused)
 {
 	char msgbuf[100];
 	int len;
@@ -1324,8 +1343,7 @@ aborthttp(notused)
  * is still open (e.g, ftp xfer with trailing /)
  */
 static int
-fetch_ftp(url)
-	const char *url;
+fetch_ftp(const char *url)
 {
 	char		*cp, *xargv[5], rempath[MAXPATHLEN];
 	char		*host, *path, *dir, *file, *user, *pass;
@@ -1435,7 +1453,8 @@ fetch_ftp(url)
 	}
 	if (debug)
 		fprintf(ttyout,
-    "fetch_ftp: user `%s' pass `%s' host %s:%s path `%s' dir `%s' file `%s'\n",
+		    "fetch_ftp: user `%s' pass `%s' host %s port %s "
+		    "path `%s' dir `%s' file `%s'\n",
 		    user ? user : "<null>", pass ? pass : "<null>",
 		    host ? host : "<null>", port ? port : "<null>",
 		    path ? path : "<null>",
@@ -1654,8 +1673,7 @@ cleanup_fetch_ftp:
  * is still open (e.g, ftp xfer with trailing /)
  */
 static int
-go_fetch(url)
-	const char *url;
+go_fetch(const char *url)
 {
 	char *proxy;
 
@@ -1677,8 +1695,14 @@ go_fetch(url)
 "NetBSD is a freely available and redistributable UNIX-like operating system.\n"
 "For more information, see http://www.netbsd.org/index.html\n", ttyout);
 		} else if (strcasecmp(url, "version") == 0) {
-			fprintf(ttyout, "Version: %s %s\n",
-			    FTP_PRODUCT, FTP_VERSION);
+			fprintf(ttyout, "Version: %s %s%s\n",
+			    FTP_PRODUCT, FTP_VERSION,
+#ifdef INET6
+			    ""
+#else
+			    " (-IPv6)"
+#endif
+			);
 		} else {
 			fprintf(ttyout, "`%s' is an interesting topic.\n", url);
 		}
@@ -1719,9 +1743,7 @@ go_fetch(url)
  * Otherwise, 0 is returned if all files retrieved successfully.
  */
 int
-auto_fetch(argc, argv)
-	int argc;
-	char *argv[];
+auto_fetch(int argc, char *argv[])
 {
 	volatile int	argpos;
 	int		rval;
@@ -1757,3 +1779,80 @@ auto_fetch(argc, argv)
 		disconnect(0, NULL);
 	return (rval);
 }
+
+
+int
+auto_put(int argc, char **argv, const char *uploadserver)
+{
+	char	*uargv[4], *path, *pathsep;
+	int	 uargc, rval, len;
+
+	uargc = 0;
+	uargv[uargc++] = "mput";
+	uargv[uargc++] = argv[0];
+	uargv[2] = uargv[3] = NULL;
+	pathsep = NULL;
+	rval = 1;
+
+	if (debug)
+		fprintf(ttyout, "auto_put: target `%s'\n", uploadserver);
+
+	path = xstrdup(uploadserver);
+	len = strlen(path);
+	if (path[len - 1] != '/' && path[len - 1] != ':') {
+			/*
+			 * make sure we always pass a directory to auto_fetch
+			 */
+		if (argc > 1) {		/* more than one file to upload */
+			int len;
+
+			len = strlen(uploadserver) + 2;	/* path + "/" + "\0" */
+			free(path);
+			path = (char *)xmalloc(len);
+			(void)strlcpy(path, uploadserver, len);
+			(void)strlcat(path, "/", len);
+		} else {		/* single file to upload */
+			uargv[0] = "put";
+			pathsep = strrchr(path, '/');
+			if (pathsep == NULL) {
+				pathsep = strrchr(path, ':');
+				if (pathsep == NULL) {
+					warnx("Invalid URL `%s'", path);
+					goto cleanup_auto_put;
+				}
+				pathsep++;
+				uargv[2] = xstrdup(pathsep);
+				pathsep[0] = '/';
+			} else 
+				uargv[2] = xstrdup(pathsep + 1);
+			pathsep[1] = '\0';
+			uargc++;
+		}
+	}
+	if (debug)
+		fprintf(ttyout, "autoput: url `%s' argv[2] `%s'\n",
+		    path, uargv[2] ? uargv[2] : "<null>");
+		
+			/* connect and cwd */		 
+	rval = auto_fetch(1, &path);
+	free(path);
+	if(rval >= 0)
+		goto cleanup_auto_put;
+
+			/* XXX : is this the best way? */
+	if (uargc == 3) {
+		uargv[1] = argv[0];
+		put(uargc, uargv);
+		goto cleanup_auto_put;
+	}
+
+	for(; argv[0] != NULL; argv++) {
+		uargv[1] = argv[0];	
+		mput(uargc, uargv);
+	}
+	rval = 0;
+
+cleanup_auto_put:
+	FREEPTR(uargv[2]);
+	return (rval);
+}
