@@ -1,7 +1,7 @@
-/*	$NetBSD: ftp.c,v 1.90 2000/01/31 22:01:04 lukem Exp $	*/
+/*	$NetBSD: ftp.c,v 1.98 2000/06/05 09:22:53 lukem Exp $	*/
 
 /*-
- * Copyright (c) 1996-1999 The NetBSD Foundation, Inc.
+ * Copyright (c) 1996-2000 The NetBSD Foundation, Inc.
  * All rights reserved.
  *
  * This code is derived from software contributed to The NetBSD Foundation
@@ -111,7 +111,7 @@ int	ptabflg;
 int	ptflag = 0;
 char	pasv[BUFSIZ];	/* passive port for proxy data connection */
 
-static int empty __P((FILE *, FILE *, int));
+static int empty(FILE *, FILE *, int);
 
 union sockunion {
 	struct sockinet {
@@ -146,12 +146,10 @@ union sockunion {
 union sockunion myctladdr, hisctladdr, data_addr;
 
 char *
-hookup(host, port)
-	char *host;
-	char *port;
+hookup(char *host, char *port)
 {
 	int s = -1, len, error;
-#ifdef NI_NUMERICHOST
+#if defined(NI_NUMERICHOST) && defined(INET6)
 	struct addrinfo hints, *res, *res0;
 	char hbuf[MAXHOSTNAMELEN];
 #else
@@ -164,7 +162,7 @@ hookup(host, port)
 	char *cause = "unknown";
 	int family;
 	
-#ifdef NI_NUMERICHOST
+#if defined(NI_NUMERICHOST) && defined(INET6)
 	memset((char *)&hisctladdr, 0, sizeof (hisctladdr));
 	memset(&hints, 0, sizeof(hints));
 	hints.ai_flags = AI_CANONNAME;
@@ -186,6 +184,25 @@ hookup(host, port)
 	hostname = hostnamebuf;
 	
 	for (res = res0; res; res = res->ai_next) {
+		/*
+		 * make sure that ai_addr is NOT an IPv4 mapped address.
+		 * IPv4 mapped address complicates too many things in FTP
+		 * protocol handling, as FTP protocol is defined differently
+		 * between IPv4 and IPv6.
+		 *
+		 * This may not be the best way to handle this situation,
+		 * since the semantics of IPv4 mapped address is defined in
+		 * the kernel.  There are configurations where we should use
+		 * IPv4 mapped address as native IPv6 address, not as
+		 * "an IPv6 address that embeds IPv4 address" (namely, SIIT).
+		 *
+		 * More complete solution would be to have an additional
+		 * getsockopt to grab "real" peername/sockname.  "real"
+		 * peername/sockname will be AF_INET if IPv4 mapped address
+		 * is used to embed IPv4 address, and will be AF_INET6 if
+		 * we use it as native.  What a mess!
+		 */
+		ai_unmapped(res);
 #if 0	/*old behavior*/
 		if (res != res0)	/* not on the first address */
 #else
@@ -313,12 +330,14 @@ hookup(host, port)
 	if (myctladdr.su_len == 0)
 		myctladdr.su_len = len;
 
+#ifdef IPTOS_LOWDELAY
 	if (family == AF_INET) {
 		int tos = IPTOS_LOWDELAY;
 		if (setsockopt(s, IPPROTO_IP, IP_TOS, (char *)&tos,
 			       sizeof(int)) < 0)
 			warn("setsockopt TOS (ignored)");
 	}
+#endif
 	cin = fdopen(s, "r");
 	cout = fdopen(s, "w");
 	if (cin == NULL || cout == NULL) {
@@ -356,8 +375,7 @@ bad:
 }
 
 void
-cmdabort(notused)
-	int notused;
+cmdabort(int notused)
 {
 	int oerrno = errno;
 
@@ -371,8 +389,7 @@ cmdabort(notused)
 }
 
 void
-cmdtimeout(notused)
-	int notused;
+cmdtimeout(int notused)
 {
 	int oerrno = errno;
 
@@ -388,28 +405,15 @@ cmdtimeout(notused)
 
 /*VARARGS*/
 int
-#ifdef __STDC__
 command(const char *fmt, ...)
-#else
-command(va_alist)
-	va_dcl
-#endif
 {
 	va_list ap;
 	int r;
 	sigfunc oldsigint;
-#ifndef __STDC__
-	const char *fmt;
-#endif
 
 	if (debug) {
 		fputs("---> ", ttyout);
-#ifdef __STDC__
 		va_start(ap, fmt);
-#else
-		va_start(ap);
-		fmt = va_arg(ap, const char *);
-#endif
 		if (strncmp("PASS ", fmt, 5) == 0)
 			fputs("PASS XXXX", ttyout);
 		else if (strncmp("ACCT ", fmt, 5) == 0)
@@ -429,12 +433,7 @@ command(va_alist)
 
 	oldsigint = xsignal(SIGINT, cmdabort);
 
-#ifdef __STDC__
 	va_start(ap, fmt);
-#else
-	va_start(ap);
-	fmt = va_arg(ap, char *);
-#endif
 	vfprintf(cout, fmt, ap);
 	va_end(ap);
 	fputs("\r\n", cout);
@@ -448,8 +447,7 @@ command(va_alist)
 }
 
 int
-getreply(expecteof)
-	int expecteof;
+getreply(int expecteof)
 {
 	char current_line[BUFSIZ];	/* last line of previous reply */
 	int c, n, line;
@@ -599,10 +597,7 @@ getreply(expecteof)
 }
 
 static int
-empty(cin, din, sec)
-	FILE *cin;
-	FILE *din;
-	int sec;
+empty(FILE *cin, FILE *din, int sec)
 {
 	int nr;
 	int nfd = 0;
@@ -663,8 +658,7 @@ empty(cin, din, sec)
 sigjmp_buf	xferabort;
 
 void
-abortxfer(notused)
-	int notused;
+abortxfer(int notused)
 {
 	char msgbuf[100];
 	int len;
@@ -690,14 +684,13 @@ abortxfer(notused)
 }
 
 void
-sendrequest(cmd, local, remote, printnames)
-	const char *cmd, *local, *remote;
-	int printnames;
+sendrequest(const char *cmd, const char *local, const char *remote,
+	    int printnames)
 {
 	struct stat st;
 	int c, d;
 	FILE *fin, *dout;
-	int (*closefunc) __P((FILE *));
+	int (*closefunc)(FILE *);
 	sigfunc oldintr, oldintp;
 	volatile off_t hashbytes;
 	char *lmode, *bufp;
@@ -994,12 +987,11 @@ cleanupsend:
 }
 
 void
-recvrequest(cmd, local, remote, lmode, printnames, ignorespecial)
-	const char *cmd, *local, *remote, *lmode;
-	int printnames, ignorespecial;
+recvrequest(const char *cmd, const char *local, const char *remote,
+	    const char *lmode, int printnames, int ignorespecial)
 {
 	FILE *fout, *din;
-	int (*closefunc) __P((FILE *));
+	int (*closefunc)(FILE *);
 	sigfunc oldintr, oldintp;
 	int c, d;
 	volatile int is_retr, tcrflag, bare_lfs;
@@ -1374,7 +1366,7 @@ cleanuprecv:
  * otherwise the server's connect may fail.
  */
 int
-initconn()
+initconn(void)
 {
 	char *p, *a;
 	int result, len, tmpno = 0;
@@ -1385,9 +1377,9 @@ initconn()
 	char *pasvcmd = NULL;
 
 #ifdef INET6
-	if (myctladdr.su_family == AF_INET6
-	 && (IN6_IS_ADDR_LINKLOCAL(&myctladdr.su_sin6.sin6_addr)
-	  || IN6_IS_ADDR_SITELOCAL(&myctladdr.su_sin6.sin6_addr))) {
+	if (myctladdr.su_family == AF_INET6 && debug &&
+	    (IN6_IS_ADDR_LINKLOCAL(&myctladdr.su_sin6.sin6_addr) ||
+	     IN6_IS_ADDR_SITELOCAL(&myctladdr.su_sin6.sin6_addr))) {
 		warnx("use of scoped address can be troublesome");
 	}
 #endif
@@ -1630,12 +1622,14 @@ reinit:
 			warn("connect");
 			goto bad;
 		}
+#ifdef IPTOS_THROUGHPUT
 		if (data_addr.su_family == AF_INET) {
 			on = IPTOS_THROUGHPUT;
 			if (setsockopt(data, IPPROTO_IP, IP_TOS, (char *)&on,
 				       sizeof(int)) < 0)
 				warn("setsockopt TOS (ignored)");
 		}
+#endif
 		return (0);
 	}
 
@@ -1756,12 +1750,14 @@ noport:
 	}
 	if (tmpno)
 		sendport = 1;
+#ifdef IPTOS_THROUGHPUT
 	if (data_addr.su_family == AF_INET) {
 		on = IPTOS_THROUGHPUT;
 		if (setsockopt(data, IPPROTO_IP, IP_TOS, (char *)&on,
 			       sizeof(int)) < 0)
 			warn("setsockopt TOS (ignored)");
 	}
+#endif
 	return (0);
 bad:
 	(void)close(data), data = -1;
@@ -1771,8 +1767,7 @@ bad:
 }
 
 FILE *
-dataconn(lmode)
-	const char *lmode;
+dataconn(const char *lmode)
 {
 	union sockunion from;
 	int s, fromlen = myctladdr.su_len;
@@ -1788,6 +1783,7 @@ dataconn(lmode)
 	}
 	(void)close(data);
 	data = s;
+#ifdef IPTOS_THROUGHPUT
 	if (from.su_family == AF_INET) {
 		int tos = IPTOS_THROUGHPUT;
 		if (setsockopt(s, IPPROTO_IP, IP_TOS, (char *)&tos,
@@ -1795,12 +1791,12 @@ dataconn(lmode)
 			warn("setsockopt TOS (ignored)");
 		}
 	}
+#endif
 	return (fdopen(data, lmode));
 }
 
 void
-psabort(notused)
-	int notused;
+psabort(int notused)
 {
 	int oerrno = errno;
 
@@ -1810,8 +1806,7 @@ psabort(notused)
 }
 
 void
-pswitch(flag)
-	int flag;
+pswitch(int flag)
 {
 	sigfunc oldintr;
 	static struct comvars {
@@ -1898,8 +1893,7 @@ pswitch(flag)
 }
 
 void
-abortpt(notused)
-	int notused;
+abortpt(int notused)
 {
 
 	alarmtimer(0);
@@ -1912,8 +1906,7 @@ abortpt(notused)
 }
 
 void
-proxtrans(cmd, local, remote)
-	const char *cmd, *local, *remote;
+proxtrans(const char *cmd, const char *local, const char *remote)
 {
 	sigfunc oldintr;
 	int prox_type, nfnd;
@@ -2052,9 +2045,7 @@ abort:
 }
 
 void
-reset(argc, argv)
-	int argc;
-	char *argv[];
+reset(int argc, char *argv[])
 {
 	int nfnd = 1;
 
@@ -2074,8 +2065,7 @@ reset(argc, argv)
 }
 
 char *
-gunique(local)
-	const char *local;
+gunique(const char *local)
 {
 	static char new[MAXPATHLEN];
 	char *cp = strrchr(local, '/');
@@ -2127,8 +2117,7 @@ gunique(local)
  *	needs to get back to a known state.
  */
 void
-abort_squared(dummy)
-	int dummy;
+abort_squared(int dummy)
 {
 	char msgbuf[100];
 	int len;
@@ -2142,8 +2131,7 @@ abort_squared(dummy)
 }
 
 void
-abort_remote(din)
-	FILE *din;
+abort_remote(FILE *din)
 {
 	char buf[BUFSIZ];
 	int nfnd;
@@ -2183,3 +2171,32 @@ abort_remote(din)
 	}
 	(void)getreply(0);
 }
+
+void
+ai_unmapped(struct addrinfo *ai)
+{
+#ifdef INET6
+	struct sockaddr_in6 *sin6;
+	struct sockaddr_in sin;
+
+	if (ai->ai_family != AF_INET6)
+		return;
+	if (ai->ai_addrlen != sizeof(struct sockaddr_in6) ||
+	    sizeof(sin) > ai->ai_addrlen)
+		return;
+	sin6 = (struct sockaddr_in6 *)ai->ai_addr;
+	if (!IN6_IS_ADDR_V4MAPPED(&sin6->sin6_addr))
+		return;
+
+	memset(&sin, 0, sizeof(sin));
+	sin.sin_family = AF_INET;
+	sin.sin_len = sizeof(struct sockaddr_in);
+	memcpy(&sin.sin_addr, &sin6->sin6_addr.s6_addr[12],
+	    sizeof(sin.sin_addr));
+	sin.sin_port = sin6->sin6_port;
+
+	ai->ai_family = AF_INET;
+	memcpy(ai->ai_addr, &sin, sin.sin_len);
+	ai->ai_addrlen = sin.sin_len;
+#endif
+}
