@@ -1,7 +1,7 @@
-/*	$NetBSD: main.c,v 1.69 1999/11/28 06:32:05 lukem Exp $	*/
+/*	$NetBSD: main.c,v 1.71 2000/05/31 14:23:59 lukem Exp $	*/
 
 /*-
- * Copyright (c) 1996-1999 The NetBSD Foundation, Inc.
+ * Copyright (c) 1996-2000 The NetBSD Foundation, Inc.
  * All rights reserved.
  *
  * This code is derived from software contributed to The NetBSD Foundation
@@ -114,18 +114,16 @@
 
 char * __progname;
 
-static void	setupoption __P((char *, char *, char *));
-int		main __P((int, char **));
+static void	setupoption(char *, char *, char *);
+int		main(int, char *[]);
 
 int
-main(argc, argv)
-	int argc;
-	char *argv[];
+main(int argc, char *argv[])
 {
 	int ch, rval;
 	struct passwd *pw = NULL;
-	char *cp, *ep, *anonuser, *anonpass;
-	int dumbterm, s, len;
+	char *cp, *ep, *anonuser, *anonpass, *upload_path;
+	int dumbterm, s, len, isupload;
 
 	__progname  = strrchr(argv[0], '/');
 	if (__progname == NULL)
@@ -170,6 +168,8 @@ main(argc, argv)
 	epsv4 = 0;
 #endif
 	epsv4bad = 0;
+	upload_path = NULL;
+	isupload = 0;
 
 	/*
 	 * Get the default socket buffer sizes if we don't already have them.
@@ -254,7 +254,7 @@ main(argc, argv)
 		}
 	}
 
-	while ((ch = getopt(argc, argv, "Aadefgino:pP:r:RtT:vV")) != -1) {
+	while ((ch = getopt(argc, argv, "Aadefgino:pP:r:RtT:u:vV")) != -1) {
 		switch (ch) {
 		case 'A':
 			activefallback = 0;
@@ -347,6 +347,16 @@ main(argc, argv)
 			break;
 		}
 
+		case 'u':
+		{
+			/* XXX : if i move this under 'T' we get a segv. */
+			isupload = 1;
+			interactive = 0;
+			upload_path = xstrdup(optarg);
+
+			break;
+		}
+
 		case 'v':
 			progress = verbose = 1;
 			break;
@@ -425,7 +435,11 @@ main(argc, argv)
 #endif
 
 	if (argc > 0) {
-		if (strchr(argv[0], ':') != NULL && ! isipv6addr(argv[0])) {
+		if (isupload) {
+			rval = auto_put(argc, argv, upload_path);
+			exit(rval);
+		} else if (strchr(argv[0], ':') != NULL
+			    && ! isipv6addr(argv[0])) {
 			rval = auto_fetch(argc, argv);
 			if (rval >= 0)		/* -1 == connected and cd-ed */
 				exit(rval);
@@ -473,6 +487,9 @@ main(argc, argv)
 			retry_connect = 0; /* connected, stop hiding msgs */
 		}
 	}
+	if (isupload)
+		usage();
+
 #ifndef NO_EDITCOMPLETE
 	controlediting();
 #endif /* !NO_EDITCOMPLETE */
@@ -488,7 +505,7 @@ main(argc, argv)
  * Generate a prompt
  */
 char *
-prompt()
+prompt(void)
 {
 	static char	**prompt;
 	static char	  buf[MAXPATHLEN];
@@ -509,7 +526,7 @@ prompt()
  * Generate an rprompt
  */
 char *
-rprompt()
+rprompt(void)
 {
 	static char	**rprompt;
 	static char	  buf[MAXPATHLEN];
@@ -530,7 +547,7 @@ rprompt()
  * Command parser.
  */
 void
-cmdscanner()
+cmdscanner(void)
 {
 	struct cmd	*c;
 	char		*p;
@@ -628,8 +645,7 @@ cmdscanner()
 }
 
 struct cmd *
-getcmd(name)
-	const char *name;
+getcmd(const char *name)
 {
 	const char *p, *q;
 	struct cmd *c, *found;
@@ -666,7 +682,7 @@ getcmd(name)
 int slrflag;
 
 void
-makeargv()
+makeargv(void)
 {
 	char *argp;
 
@@ -709,7 +725,7 @@ makeargv()
  * handle quoting and strings
  */
 char *
-slurpstring()
+slurpstring(void)
 {
 	int got_one = 0;
 	char *sb = stringbase;
@@ -841,9 +857,7 @@ OUT:
  * Call each command handler with argc == 0 and argv[0] == name.
  */
 void
-help(argc, argv)
-	int argc;
-	char *argv[];
+help(int argc, char *argv[])
 {
 	struct cmd *c;
 	char *nargv[1], *p, *cmd;
@@ -895,8 +909,7 @@ help(argc, argv)
 }
 
 struct option *
-getoption(name)
-	const char *name;
+getoption(const char *name)
 {
 	const char *p;
 	struct option *c;
@@ -911,8 +924,7 @@ getoption(name)
 }
 
 char *
-getoptionvalue(name)
-	const char *name;
+getoptionvalue(const char *name)
 {
 	struct option *c;
 
@@ -925,8 +937,7 @@ getoptionvalue(name)
 }
 
 static void
-setupoption(name, value, defaultvalue)
-	char *name, *value, *defaultvalue;
+setupoption(char *name, char *value, char *defaultvalue)
 {
 	char *nargv[3];
 	int overbose;
@@ -941,12 +952,13 @@ setupoption(name, value, defaultvalue)
 }
 
 void
-usage()
+usage(void)
 {
 	(void)fprintf(stderr,
-"usage: %s [-AadefginpRtvV] [-o outfile] [-P port] [-r retry] [-T dir,max[,inc]\n"
-"       [[user@]host [port]] [host:path[/]] [file:///file]\n"
-"       [ftp://[user[:pass]@]host[:port]/path[/]]\n"
-"       [http://[user[:pass]@]host[:port]/path] [...]\n", __progname);
+"usage: %s [-AadefginpRtvV] [-o outfile] [-P port] [-r retry]\n"
+"           [-T dir,max[,inc][[user@]host [port]]] [host:path[/]]\n"
+"           [file:///file] [ftp://[user[:pass]@]host[:port]/path[/]]\n"
+"           [http://[user[:pass]@]host[:port]/path] [...]\n"
+"       %s -u url file [...]\n", __progname, __progname);
 	exit(1);
 }
